@@ -7,7 +7,7 @@
 
 #include "ReaderOptions.h"
 #include "ImageView.h"
-#include "Result.h"
+#include "Barcode.h"
 
 namespace ZXing {
 
@@ -16,18 +16,18 @@ namespace ZXing {
  *
  * @param image  view of the image data including layout and format
  * @param options  optional ReaderOptions to parameterize / speed up detection
- * @return #Result structure
+ * @return #Barcode structure
  */
-Result ReadBarcode(const ImageView& image, const ReaderOptions& options = {});
+Barcode ReadBarcode(const ImageView& image, const ReaderOptions& options = {});
 
 /**
  * Read barcodes from an ImageView
  *
  * @param image  view of the image data including layout and format
  * @param options  optional ReaderOptions to parameterize / speed up detection
- * @return #Results list of results found, may be empty
+ * @return #Barcodes  list of barcodes found, may be empty
  */
-Results ReadBarcodes(const ImageView& image, const ReaderOptions& options = {});
+Barcodes ReadBarcodes(const ImageView& image, const ReaderOptions& options = {});
 
 } // ZXing
 
